==> termaitrik-1.2.3-py3-none-any.whl: termai/prompts.py <==
from __future__ import annotations

def get_system_info() -> str:
    import platform
    import shutil

    info = [
        f"OS: {platform.system()} {platform.release()} ({platform.version()})",
        f"Machine: {platform.machine()}",
        f"Python: {platform.python_version()}",
        f"Shell: {shutil.which('bash') and 'bash' or shutil.which('zsh') and 'zsh' or shutil.which('sh') and 'sh' or 'unknown'}",
    ]
    return "\n".join(info)

SYSTEM_SHELL_EXPERT = f"""You are computer terminal shell assistant.
- Use the current system default shell (e.g. bash, zsh, sh).
- Use commands available on the system (no custom tools).
- Be concise.
- When you suggest a command, also add a short explanation and main risks.
- Never execute commands yourself.
- Always wait for explicit user approval before any action.

System info:
{get_system_info()}
"""

PROMPT_SUGGEST = """The user describes a goal. Generate up to 3 safe shell commands that help reach the goal.
Respond ONLY in JSON with this exact schema:
{{
  "commands": [
    {{"cmd": "string", "why": "short reason", "risks": "main risks or 'none'"}}
  ]
}}
Rules:
- Prefer simple, widely available tools.
- Do not chain too many actions in one command if multiple steps would be clearer.
- If the goal is unclear, include one item with a clarifying question instead of a risky guess.
Goal: {goal}
Context: {context}
"""

PROMPT_EXPLAIN = """Explain clearly and briefly what this shell command does:
{cmd}
Include:
- Step by step breakdown
- Important flags
- Main risks (if any)
- 1-2 safe useful variations
"""

PROMPT_FIX = """You have a failed command and its error output.
Tasks:
1. Infer the most likely cause (one sentence).
2. Propose up to 3 alternative fix commands.
Respond ONLY in JSON with this schema:
{{
  "cause": "string",
  "fixes": [ {{"cmd": "string", "why": "why it should work"}} ]
}}
Command: {cmd}
Error:
{err}
"""

# --- Minimal agent mode prompts (experimental) ---

AGENT_SYSTEM_PROMPT = """You are an iterative shell planner.
At each step you output ONLY one JSON object (no extra text) with keys:
{{
  "thought": "short reasoning",
  "command": "a safe shell command or empty string",
  "explanation": "why this command helps",
  "done": true|false
}}
Rules:
- Keep reasoning short (one sentence).
- Use simple, portable commands.
- Avoid destructive actions unless explicitly requested.
- If the goal is fully achieved set done=true and leave command empty.
- Never include anything outside the JSON.
"""

AGENT_STEP_USER_PROMPT = """Global goal: {goal}

Recent history (latest events):
{history_snippet}

Return ONLY the next JSON object (see schema). If finished: set "done": true and "command": "".
No extra commentary.
"""

==> termaitrik-1.7.1-py3-none-any.whl: termai/prompts.py <==
from __future__ import annotations

def get_system_info() -> str:
    import platform
    import shutil

    info = [
        f"OS: {platform.system()} {platform.release()} ({platform.version()})",
        f"Machine: {platform.machine()}",
        f"Python: {platform.python_version()}",
        f"Shell: {shutil.which('bash') and 'bash' or shutil.which('zsh') and 'zsh' or shutil.which('sh') and 'sh' or 'unknown'}",
    ]
    return "\n".join(info)

SYSTEM_SHELL_EXPERT = f"""You are computer terminal shell assistant.
- Use the current system default shell (e.g. bash, zsh, sh).
- Use commands available on the system (no custom tools).
- Be concise.
- When you suggest a command, also add a short explanation and main risks.
- Never execute commands yourself.
- Always wait for explicit user approval before any action.

System info:
{get_system_info()}
"""

GENERIC_CHAT_PROMPT = """You are a helpful AI assistant.
- Provide clear and accurate information
- Be friendly and engaging in your responses
- If you don't know something, admit it rather than making up information
- Keep explanations concise but complete
- Adapt your response style to the user's questions
"""

PROMPT_SUGGEST = """The user describes a goal. Generate up to 3 safe shell commands that help reach the goal.
Respond ONLY in JSON with this exact schema:
{{
  "commands": [
    {{"cmd": "string", "why": "short reason", "risks": "main risks or 'none'"}}
  ]
}}
Rules:
- Prefer simple, widely available tools.
- Do not chain too many actions in one command if multiple steps would be clearer.
- If the goal is unclear, include one item with a clarifying question instead of a risky guess.
Goal: {goal}
Context: {context}
"""

PROMPT_EXPLAIN = """Explain clearly and briefly what this shell command does:
{cmd}
Include:
- Step by step breakdown
- Important flags
- Main risks (if any)
- 1-2 safe useful variations
"""

PROMPT_FIX = """You have a failed command and its error output.
Tasks:
1. Infer the most likely cause (one sentence).
2. Propose up to 3 alternative fix commands.
Respond ONLY in JSON with this schema:
{{
  "cause": "string",
  "fixes": [ {{"cmd": "string", "why": "why it should work"}} ]
}}
Command: {cmd}
Error:
{err}
"""

# --- Minimal agent mode prompts (experimental) ---

AGENT_SYSTEM_PROMPT = """You are an iterative shell planner.
At each step you output ONLY one JSON object (no extra text) with keys:
{{
  "thought": "short reasoning",
  "command": "a safe shell command or empty string",
  "explanation": "why this command helps",
  "done": true|false
}}
Rules:
- Keep reasoning short (one sentence).
- Use simple, portable commands.
- Avoid destructive actions unless explicitly requested.
- If the goal is fully achieved set done=true and leave command empty.
- Never include anything outside the JSON.
"""

AGENT_STEP_USER_PROMPT = """Global goal: {goal}

Recent history (latest events):
{history_snippet}

Return ONLY the next JSON object (see schema). If finished: set "done": true and "command": "".
No extra commentary.
"""
